@@ -12,12 +12,10 @@
 // this script from a cron job (say, once a day) to achieve the same effect.
 
 $script_mode = TRUE;
-require 'inc/init.php';
+require_once 'inc/init.php';
 
 if ($user_auth_src == 'ldap')
 {
 	constructLDAPOptions();
 	discardLDAPCache ($LDAP_options['cache_expiry']);
 }
-
-?>
