@@ -181,7 +181,7 @@ class ERetryNeeded extends RackTablesError
 class InvalidArgException extends RackTablesError
 {
 	// derive an instance of InvalidRequestArgException
-	function newIRAE ($argname = NULL)
+	public function newIRAE ($argname = NULL)
 	{
 		if ($argname === NULL)
 			return new InvalidRequestArgException ($this->name, $this->value, $this->reason);
@@ -198,6 +198,19 @@ class InvalidArgException extends RackTablesError
 		$this->value = $value;
 		$this->reason = $reason;
 	}
+	// Instead of the two methods below it would be better to have a single method
+	// like setArgumentName() in order not to expose unnecessary details to the
+	// users of the class. However, this is not possible because the Exception
+	// class does not allow to redefine the message string, which the constructor
+	// assigns based on the argument name.
+	public function getValue()
+	{
+		return $this->value;
+	}
+	public function getReason()
+	{
+		return $this->reason;
+	}
 }
 
 // this simplifies construction and helps in catching "soft"
@@ -210,8 +223,8 @@ class InvalidRequestArgException extends InvalidArgException
 	}
 }
 
-// this wraps certain known PDO errors and is caught in process.php
-// as a "soft" error
+// This wraps certain known PDO errors and is caught in index.php?module=redirect
+// and elsewhere to be handled as a "soft" error.
 class RTDatabaseError extends RackTablesError
 {
 	public function dispatch()
@@ -220,6 +233,19 @@ class RTDatabaseError extends RackTablesError
 	}
 }
 
+// This specifically means the error condition that happens when the database user
+// does not have the privileges to execute the query. The code that catches this
+// exception class has to interpret what it actually means based on the query it
+// was trying to execute. If not specifically expected, the exception will end up
+// in the same catch blocks as RTDatabaseError.
+class RTDBTableAccessDenied extends RTDatabaseError
+{
+	public function dispatch()
+	{
+		RackTablesError::genHTMLPage ('Database table access denied', '<h2>Database table access denied</h2><br>' . $this->message);
+	}
+};
+
 // gateway failure is a common case of a "soft" error, some functions do catch this
 class RTGatewayError extends RackTablesError
 {
@@ -229,7 +255,7 @@ class RTGatewayError extends RackTablesError
 	}
 }
 
-# "Permission denied" is a very common case, which in some situations is
+# "Permission denied" is a very common case that in some situations is
 # treated as a "soft" error.
 class RTPermissionDenied extends RackTablesError
 {
@@ -309,11 +335,34 @@ class RTImageError extends RackTablesError
 	}
 }
 
+function dumpArrayElement ($x)
+{
+	switch (gettype ($x))
+	{
+	case 'integer':
+		echo $x;
+		break;
+	case 'array':
+		dumpArray ($x);
+		break;
+	default:
+		echo stringForTD ($x, 100);
+	}
+}
+
 function dumpArray ($arr)
 {
-	echo '<table class="exceptionParametersDump">';
+	$self = __FUNCTION__;
+	echo '<table><caption>(array)</caption>';
 	foreach ($arr as $key => $value)
-		echo '<tr><th>' . stringForTD ($key) . '</th><td>' . stringForTD ($value, 100) . '</td></tr>';
+	{
+		echo '<tr valign=top><th class=tdright>';
+		// stringForTD() does not handle key 0 properly.
+		dumpArrayElement ($key);
+		echo '</th><td>';
+		dumpArrayElement ($value);
+		echo '</td></tr>';
+	}
 	echo '</table>';
 }
 
@@ -410,5 +459,3 @@ function printException ($e)
 	else
 		printGenericException ($e);
 }
-
-?>
