@@ -449,11 +449,24 @@ function printImageHREF ($tag, $title = '', $do_input = FALSE)
 function getImageHREF ($tag, $title = '', $do_input = FALSE)
 {
 	global $image;
+
+	$src = NULL;
+	if (array_key_exists ($tag, $image))
+	{
+		$srctype = array_fetch ($image[$tag], 'srctype', 'intpath');
+		if ($srctype == 'intpath' && array_key_exists ('path', $image[$tag]))
+			$src = '?module=chrome&uri=' . $image[$tag]['path'];
+		elseif ($srctype == 'dataurl' && array_key_exists ('data', $image[$tag]))
+			$src = 'data:' . $image[$tag]['data'];
+		elseif ($srctype == 'exturl' && array_key_exists ('url', $image[$tag]))
+			$src = $image[$tag]['url'];
+	}
+	if ($src === NULL)
+		throw new RackTablesError ("malformed \$image declaration for '$tag'");
+
 	$attrs = array
 	(
-		'src' => array_key_exists ($tag, $image) ?
-			'?module=chrome&uri=' . $image[$tag]['path'] :
-			'?module=image&img=error',
+		'src' => $src,
 		'border' => 0,
 	);
 	if ($title != '')
@@ -469,10 +482,11 @@ function getImageHREF ($tag, $title = '', $do_input = FALSE)
 	else
 	{
 		$element = 'img';
-		if (array_key_exists ($tag, $image))
+		foreach (array ('width', 'height') as $each)
 		{
-			$attrs['width'] = $image[$tag]['width'];
-			$attrs['height'] = $image[$tag]['height'];
+			if (! array_key_exists ($each, $image[$tag]))
+				throw new RackTablesError ("no '$each' in \$image['$tag']");
+			$attrs[$each] = $image[$tag][$each];
 		}
 	}
 	return makeHtmlTag ($element, $attrs);
