@@ -17,6 +17,7 @@ SELECT
 	pii.iif_name,
 	poi.oif_name,
 	p.object_id,
+	o.objtype_id as object_tid,
 	o.name as object_name
 FROM Port p
 INNER JOIN Object o ON o.id = p.object_id
@@ -123,7 +124,8 @@ INNER JOIN (
 			foreach (sortPortList ($rows_by_pn) as $ports_subarray)
 				foreach ($ports_subarray as $port_row)
 				{
-					$port_description = $port_row['object_name'] . ' --  ' . $port_row['name'];
+					$port_description = formatObjectDisplayedName ($port_row['object_name'], $port_row['object_tid']) .
+						' --  ' . $port_row['name'];
 					if (count ($ports_subarray) > 1)
 					{
 						$if_type = $port_row['iif_id'] == 1 ? $port_row['oif_name'] : $port_row['iif_name'];
@@ -135,7 +137,7 @@ INNER JOIN (
 				}
 			$rows_by_pn = array();
 		}
-		$prev_object_id = $row['object_id'];
+		$prev_object_id = $row['object_id'] ?? "";
 		if ($row)
 			$rows_by_pn[$row['name']][] = $row;
 		else
@@ -153,7 +155,7 @@ function findObjectParentCandidates ($object_id)
 	$object = spotEntity ('object', $object_id);
 	$args = array ($object['objtype_id'], $object_id, $object_id);
 
-	$query  = "SELECT O.id, O.name, O.objtype_id FROM Object O ";
+	$query = "SELECT O.id, O.name, O.objtype_id FROM Object O ";
 	$query .= "LEFT JOIN ObjectParentCompat OPC ON O.objtype_id = OPC.parent_objtype_id ";
 	$query .= "WHERE OPC.child_objtype_id = ? ";
 	$query .= "AND O.id != ? ";
@@ -191,8 +193,7 @@ function sortObjectAddressesAndNames ($a, $b)
 		$name_b = (isset ($b['port_name'])) ? $b['port_name'] : '';
 		$objname_cmp = sortTokenize($name_a, $name_b);
 		if ($objname_cmp == 0)
-			sortTokenize($a['ip'], $b['ip']);
-		return $objname_cmp;
+			$objname_cmp = sortTokenize ($a['ip'], $b['ip']);
 	}
 	return $objname_cmp;
 }
@@ -216,8 +217,8 @@ function renderPopupObjectSelector()
 function handlePopupPortLink()
 {
 	assertPermission('depot', 'default');
-	assertUIntArg ('port');
-	assertUIntArg ('remote_port');
+	genericAssertion ('port', 'natural');
+	genericAssertion ('remote_port', 'natural');
 	assertStringArg ('cable', TRUE);
 	$port_info = getPortInfo ($_REQUEST['port']);
 	$remote_port_info = getPortInfo ($_REQUEST['remote_port']);
@@ -263,30 +264,31 @@ function handlePopupPortLink()
 					showError ('failed to consume a patch cable');
 			}
 		}
-		showOneLiner 
+		showOneLiner
 		(
-			8, 
+			8,
 			array
 			(
 				formatPortLink ($port_info['object_id'], NULL, $port_info['id'], $port_info['name']),
 				formatPort ($remote_port_info),
 			)
 		);
-		addJS (<<<END
+		addJSText (<<<'END'
 window.opener.location.reload(true);
 window.close();
 END
-		, TRUE);
+		);
 		backupLogMessages();
 	}
 	else
 	{
 		// JS code to display port compatibility hint
-		addJS (<<<END
+		// Heredoc, not nowdoc!
+		addJSText (<<<"END"
 POIFC = {};
 $js_table
 $(document).ready(function () {
-	$('select.porttype').change(onPortTypeChange);	
+	$('select.porttype').change(onPortTypeChange);
 	onPortTypeChange();
 });
 function onPortTypeChange() {
@@ -303,8 +305,8 @@ function onPortTypeChange() {
 	}
 }
 END
-		, TRUE);
-		addCSS (<<<END
+		);
+		addCSSText (<<<'END'
 .compat-hint {
 	display: none;
 	font-size: 125%;
@@ -316,7 +318,7 @@ END
 	color: #804040;
 }
 END
-		, TRUE);
+		);
 		// render port type editor form
 		echo '<form method=GET>';
 		echo '<input type=hidden name="module" value="popup">';
@@ -362,7 +364,7 @@ function renderPopupPortSelector()
 	if (isset ($_REQUEST['do_link']))
 		return handlePopupPortLink();
 	assertPermission('depot', 'default');
-	assertUIntArg ('port');
+	genericAssertion ('port', 'natural');
 	$port_id = $_REQUEST['port'];
 	$port_info = getPortInfo ($port_id);
 	$in_rack = isCheckSet ('in_rack');
@@ -403,7 +405,8 @@ function renderPopupPortSelector()
 	)
 		$spare_ports = findSparePorts ($port_info, $filter);
 
-	includeJQueryUI (TRUE);
+	includeJQueryUIJS();
+	includeJQueryUICSS();
 
 	// display search form
 	echo 'Link ' . formatPort ($port_info) . ' to...';
@@ -421,7 +424,7 @@ function renderPopupPortSelector()
 	echo '</tr></table>';
 	finishPortlet();
 
-	addJS (<<<JSEND
+	addJSText (<<<'JSEND'
 		$(document).ready( function() {
 			$("#filter-obj").autocomplete({
 				source: "?module=ajax&ac=autocomplete&realm=object",
@@ -461,7 +464,7 @@ function renderPopupPortSelector()
 			});
 		});
 JSEND
-	, TRUE);
+	);
 
 	// display results
 	startPortlet ('Compatible spare ports');
@@ -485,11 +488,16 @@ JSEND
 function renderPopupIPv4Selector()
 {
 	assertPermission('ipv4space', 'default');
-	echo '<h2>Choose a port:</h2><br><br>';
+	echo '<h2>Choose an IPv4 allocation:</h2><br><br>';
 	echo '<form action="javascript:;">';
 	echo '<input type=hidden id=ip>';
 	echo '<select size=' . getConfigVar ('MAXSELSIZE') . ' id=addresses>';
-	$addresses = getAllIPv4Allocations();
+	$addresses = array();
+	foreach (getAllIPv4Allocations() as $each)
+	{
+		$each['object_name'] = formatObjectDisplayedName ($each['object_name'], $each['objtype_id']);
+		$addresses[] = $each;
+	}
 	usort ($addresses, 'sortObjectAddressesAndNames');
 	foreach ($addresses as $address)
 		echo "<option value='${address['ip']}' onclick='getElementById(\"ip\").value=\"${address['ip']}\";'>" .
@@ -504,16 +512,14 @@ function renderPopupIPv4Selector()
 
 function renderPopupHTML ($contents)
 {
-?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en" style="height: 100%;">
-<head>
-<title>RackTables pop-up</title>
-<?php printPageHeaders(); ?>
-</head>
-<body style="height: 100%;">
-<div class="popupbar"><?php echo $contents; ?></div>
-</body>
-</html>
-<?php
+	echo "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n";
+	echo '<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en" style="height: 100%;">';
+	echo '<head>';
+	echo '<title>RackTables pop-up</title>';
+	printPageHeaders();
+	echo '</head>';
+	echo '<body style="height: 100%;">';
+	echo "<div class=popupbar>${contents}</div>";
+	echo '</body>';
+	echo '</html>';
 }
-?>
