@@ -187,6 +187,11 @@ and "addCSSExternal()" functions.  The "addCSS()" function will likely be remove
 
 For more information on the "addJS()" and "addCSS()" changes see the README.md
 ENDOFTEXT
+,
+
+	'0.22.0' => <<<'ENDOFTEXT'
+As of this release the minimum supported PHP version is 7.0.
+ENDOFTEXT
 ,
 );
 
@@ -220,6 +225,7 @@ function getDBUpgradePath ($v1, $v2)
 		'0.21.3',
 		'0.21.4',
 		'0.21.5',
+		'0.22.0',
 	);
 	if (! in_array ($v1, $versionhistory) || ! in_array ($v2, $versionhistory))
 		return NULL;
@@ -418,9 +424,9 @@ CREATE VIEW `RackObject` AS SELECT id, name, label, objtype_id, asset_no, has_pr
 
 			$query[] = "INSERT INTO `Config` (varname, varvalue, vartype, emptyok, is_hidden, is_userdefined, description) VALUES ('SEARCH_DOMAINS','','string','yes','no','yes','DNS domain list (comma-separated) to search in FQDN attributes')";
 
-			// update some config variables that changed their defaults in this verison
+			// update some config variables that changed their defaults in this version
 			replaceConfigVarValue ('SHOW_LAST_TAB', 'yes');
-			replaceConfigVarValue ('IPV4_TREE_SHOW_USAGE','no');
+			replaceConfigVarValue ('IPV4_TREE_SHOW_USAGE', 'no');
 			replaceConfigVarValue ('IPV4LB_LISTSRC', 'false', '{$typeid_4}');
 			replaceConfigVarValue ('FILTER_DEFAULT_ANDOR', 'and');
 			replaceConfigVarValue ('FILTER_SUGGEST_EXTRA', 'yes');
@@ -1365,6 +1371,12 @@ INSERT INTO `Config` (varname, varvalue, vartype, emptyok, is_hidden, is_userdef
 		case '0.21.5':
 			$query[] = "UPDATE Config SET varvalue = '0.21.5' WHERE varname = 'DB_VERSION'";
 			break;
+		case '0.22.0':
+			$query[] = "INSERT INTO PortOuterInterface VALUES (441, 'HDMI')";
+			$query[] = "INSERT INTO PortCompat VALUES (441, 441)";
+			$query[] = "INSERT INTO PortInterfaceCompat VALUES (1, 441)";
+			$query[] = "UPDATE Config SET varvalue = '0.22.0' WHERE varname = 'DB_VERSION'";
+			break;
 		case 'dictionary':
 			$query = reloadDictionary();
 			break;
@@ -1446,7 +1458,7 @@ function showUpgradeError ($info = '', $location = 'N/A')
 		$location = basename ($location);
 	elseif ($location != 'N/A')
 		$location = $location . '()';
-	echo "<div class=msg_error>An error has occured in [${location}]. ";
+	echo "<div class=msg_error>An error has occurred in [${location}]. ";
 	if ($info == '')
 		echo 'No additional information is available.';
 	else
